@@ -492,12 +492,16 @@ class _MinosModelAvroDataBuilder(object):
 
 
 def _is_minos_model_cls(type_field: t.Type) -> bool:
-    from .model import MinosModel
+    from .model import (
+        MinosModel,
+    )
 
     return inspect.isclass(type_field) and issubclass(type_field, MinosModel)
 
 
 def _is_aggregate_cls(type_field: t.Type) -> bool:
-    from ..aggregate import Aggregate
+    from ..aggregate import (
+        Aggregate,
+    )
 
     return inspect.isclass(type_field) and issubclass(type_field, Aggregate)
