@@ -11,6 +11,7 @@ from typing import (
 )
 
 import pytest
+
 from minos.common import (
     EmptyMinosModelSequenceException,
     MinosAttributeValidationException,
@@ -259,6 +260,13 @@ class TestMinosModel(unittest.TestCase):
         }
         self.assertEqual(expected, customer.avro_data)
 
+    def test_avro_avro_str_single(self):
+        customer = Customer(1234)
+        avro_str = customer.avro_str
+        self.assertIsInstance(avro_str, str)
+        decoded_customer = Customer.from_avro_str(avro_str)
+        self.assertEqual(customer, decoded_customer)
+
     def test_avro_bytes_single(self):
         customer = Customer(1234)
         avro_bytes = customer.avro_bytes
@@ -266,6 +274,13 @@ class TestMinosModel(unittest.TestCase):
         decoded_customer = Customer.from_avro_bytes(avro_bytes)
         self.assertEqual(customer, decoded_customer)
 
+    def test_avro_to_avro_str(self):
+        customers = [Customer(1234), Customer(5678)]
+        avro_str = Customer.to_avro_str(customers)
+        self.assertIsInstance(avro_str, str)
+        decoded_customer = Customer.from_avro_str(avro_str)
+        self.assertEqual(customers, decoded_customer)
+
     def test_avro_bytes_sequence(self):
         customers = [Customer(1234), Customer(5678)]
         avro_bytes = Customer.to_avro_bytes(customers)
